@@ -1,6 +1,6 @@
 # pyright: reportOptionalMemberAccess=false, reportOptionalIterable=false
 
-from typing import Any, List
+from typing import Any, Callable, Optional
 
 from antlr4 import CommonTokenStream, InputStream
 
@@ -9,6 +9,22 @@ from proto_schema_parser.antlr.ProtobufLexer import ProtobufLexer
 from proto_schema_parser.antlr.ProtobufParser import ProtobufParser
 from proto_schema_parser.antlr.ProtobufParserVisitor import ProtobufParserVisitor
 
+SetupLexerCb = Callable[[ProtobufLexer], None]
+"""
+Callback function to modify the lexer during parsing.
+
+Args:
+    lexer (ProtobufLexer): The lexer instance being modified.
+"""
+
+SetupParserCb = Callable[[ProtobufParser], None]
+"""
+Callback function to modify the parser during parsing.
+
+Args:
+    parser (ProtobufParser): The parser instance being modified.
+"""
+
 
 class ASTConstructor(ProtobufParserVisitor):
     def visitFile(self, ctx: ProtobufParser.FileContext):
@@ -63,7 +79,10 @@ class ASTConstructor(ProtobufParserVisitor):
     def visitMessageLiteralField(self, ctx: ProtobufParser.MessageLiteralFieldContext):
         """Parse individual fields inside a message literal."""
         name = self._getText(ctx.messageLiteralFieldName())
-        value = self.visit(ctx.value())
+        if ctx.value():
+            value = self.visit(ctx.value())
+        else:
+            value = self.visit(ctx.messageValue())
         return ast.MessageLiteralField(name=name, value=value)
 
     def visitMessageDecl(self, ctx: ProtobufParser.MessageDeclContext):
@@ -296,20 +315,35 @@ class ASTConstructor(ProtobufParserVisitor):
     def visitIdentifier(self, ctx: ProtobufParser.IdentifierContext) -> ast.Identifier:
         return ast.Identifier(name=self._getText(ctx))
 
-    def visitValue(self, ctx: ProtobufParser.ValueContext) -> ast.MessageValue:
+    def visitValue(self, ctx: ProtobufParser.ValueContext):
+        """Parse a value, which can be a scalar, message literal, or list literal."""
         if ctx.scalarValue():
             return self.visit(ctx.scalarValue())
         elif ctx.messageLiteral():
             return self.visit(ctx.messageLiteral())
-        elif ctx.listLiteral():
+        else:  # listLiteral
             return self.visit(ctx.listLiteral())
-        else:
-            return self._getText(ctx)
+
+    def visitMessageValue(self, ctx: ProtobufParser.MessageValueContext):
+        """Parse a message value, which can be a message literal or list of message literals."""
+        if ctx.messageLiteral():
+            return self.visit(ctx.messageLiteral())
+        else:  # listOfMessagesLiteral
+            return self.visit(ctx.listOfMessagesLiteral())
 
     def visitListLiteral(self, ctx: ProtobufParser.ListLiteralContext):
-        """Parse list literals."""
-        elements = [self.visit(element) for element in ctx.listElement()]
-        return elements
+        """Parse a list literal, which can contain scalar values or message literals."""
+        if not ctx.listElement():
+            return []
+        return [self.visit(element) for element in ctx.listElement()]
+
+    def visitListOfMessagesLiteral(
+        self, ctx: ProtobufParser.ListOfMessagesLiteralContext
+    ):
+        """Parse a list of message literals."""
+        if not ctx.messageLiteral():
+            return []
+        return [self.visit(msg) for msg in ctx.messageLiteral()]
 
     def visitAlwaysIdent(self, ctx: ProtobufParser.AlwaysIdentContext):
         if ctx.IDENTIFIER():
@@ -393,11 +427,26 @@ class ASTConstructor(ProtobufParserVisitor):
 
 
 class Parser:
+    def __init__(
+        self,
+        *,
+        setup_lexer: Optional[SetupLexerCb] = None,
+        setup_parser: Optional[SetupParserCb] = None,
+    ) -> None:
+        self.setup_lexer = setup_lexer
+        self.setup_parser = setup_parser
+
     def parse(self, text: str) -> ast.File:
         input_stream = InputStream(text)
         lexer = ProtobufLexer(input_stream)
+        if self.setup_lexer:
+            self.setup_lexer(lexer)
+
         token_stream = CommonTokenStream(lexer)
         parser = ProtobufParser(token_stream)
+        if self.setup_parser:
+            self.setup_parser(parser)
+
         parse_tree = parser.file_()
         visitor = ASTConstructor()
         return visitor.visit(parse_tree)  # pyright: ignore [reportGeneralTypeIssues]
