@@ -392,7 +392,7 @@ def test_generate_service():
         "service MyService {\n"
         "  rpc MyRpc (MyRequest) returns (MyResponse);\n"
         "  rpc MyRpcWithStream (stream MyRequest) returns (MyResponse);\n"
-        "  rpc MyRpcWithOption (MyRequest) returns (MyResponse){\n"
+        "  rpc MyRpcWithOption (MyRequest) returns (MyResponse) {\n"
         '    option deprecated = "true";\n'
         "  }\n"
         '  option MyOption = "foo";\n'
@@ -937,7 +937,7 @@ def test_generate_service_with_option_message_literal():
         '    string_field: "test",\n'
         '    list_field: ["a", "b"]\n'
         "  };\n"
-        "  rpc TestMethod (TestRequest) returns (TestResponse){\n"
+        "  rpc TestMethod (TestRequest) returns (TestResponse) {\n"
         "    option method_option = {\n"
         "      inner_option: {\n"
         "        enabled: false\n"
@@ -1119,3 +1119,102 @@ def test_generate_option_with_multiple_message_literals():
     )
 
     assert result == expected
+
+
+def test_generate_field_with_options_for_scalar_types():
+    generator = Generator()
+    test_cases = [
+        # Numeric types
+        ("double", 3.14, "double field_double = 1 [default = 3.14];"),
+        ("float", -1.23, "float field_float = 2 [default = -1.23];"),
+        ("int32", -42, "int32 field_int32 = 3 [default = -42];"),
+        ("int64", 9876543210, "int64 field_int64 = 4 [default = 9876543210];"),
+        ("uint32", 42, "uint32 field_uint32 = 5 [default = 42];"),
+        ("uint64", 1234567890, "uint64 field_uint64 = 6 [default = 1234567890];"),
+        ("sint32", -123, "sint32 field_sint32 = 7 [default = -123];"),
+        ("sint64", -9876543210, "sint64 field_sint64 = 8 [default = -9876543210];"),
+        ("fixed32", 456, "fixed32 field_fixed32 = 9 [default = 456];"),
+        ("fixed64", 1234567890, "fixed64 field_fixed64 = 10 [default = 1234567890];"),
+        ("sfixed32", -789, "sfixed32 field_sfixed32 = 11 [default = -789];"),
+        (
+            "sfixed64",
+            -1234567890,
+            "sfixed64 field_sfixed64 = 12 [default = -1234567890];",
+        ),
+        # Boolean type
+        ("bool", True, "bool field_bool = 13 [default = true];"),
+        # String types
+        (
+            "string",
+            "test string",
+            'string field_string = 14 [default = "test string"];',
+        ),
+    ]
+
+    for type_name, default_value, expected in test_cases:
+        field = ast.Field(
+            name=f"field_{type_name}",
+            type=type_name,
+            number=test_cases.index((type_name, default_value, expected)) + 1,
+            options=[ast.Option(name="default", value=default_value)],
+        )
+        result = generator._generate_field(field)
+        assert result == expected
+
+
+def test_generate_service_with_additional_bindings():
+    """Test that a service with additional_bindings in google.api.http option is generated correctly."""
+    service = ast.Service(
+        name="Lease",
+        elements=[
+            ast.Method(
+                name="LeaseRevoke",
+                input_type=ast.MessageType(type="LeaseRevokeRequest", stream=False),
+                output_type=ast.MessageType(type="LeaseRevokeResponse", stream=False),
+                elements=[
+                    ast.Option(
+                        name="(google.api.http)",
+                        value=ast.MessageLiteral(
+                            fields=[
+                                ast.MessageLiteralField(
+                                    name="post", value="/v3/lease/revoke"
+                                ),
+                                ast.MessageLiteralField(name="body", value="*"),
+                                ast.MessageLiteralField(
+                                    name="additional_bindings",
+                                    value=ast.MessageLiteral(
+                                        fields=[
+                                            ast.MessageLiteralField(
+                                                name="post", value="/v3/kv/lease/revoke"
+                                            ),
+                                            ast.MessageLiteralField(
+                                                name="body", value="*"
+                                            ),
+                                        ]
+                                    ),
+                                ),
+                            ]
+                        ),
+                    )
+                ],
+            )
+        ],
+    )
+
+    result = Generator()._generate_service(service)
+    expected = (
+        "service Lease {\n"
+        "  rpc LeaseRevoke (LeaseRevokeRequest) returns (LeaseRevokeResponse) {\n"
+        "    option (google.api.http) = {\n"
+        '      post: "/v3/lease/revoke",\n'
+        '      body: "*",\n'
+        "      additional_bindings: {\n"
+        '        post: "/v3/kv/lease/revoke",\n'
+        '        body: "*"\n'
+        "      }\n"
+        "    };\n"
+        "  }\n"
+        "}"
+    )
+
+    assert result == expected
