@@ -1,3 +1,5 @@
+import pytest
+
 from proto_schema_parser import ast
 from proto_schema_parser.parser import ASTConstructor, Parser
 
@@ -1593,3 +1595,99 @@ def test_parse_bool_options():
     )
 
     assert result == expected
+
+
+def test_parse_service_with_additional_bindings():
+    """Test parsing a service with additional_bindings in google.api.http option."""
+    text = """
+    service Lease {
+        rpc LeaseRevoke(LeaseRevokeRequest) returns (LeaseRevokeResponse) {
+            option (google.api.http) = {
+                post: "/v3/lease/revoke"
+                body: "*"
+                additional_bindings {
+                    post: "/v3/kv/lease/revoke"
+                    body: "*"
+                }
+            };
+        }
+    }
+    """
+    result = Parser().parse(text)
+    expected = ast.File(
+        syntax=None,
+        file_elements=[
+            ast.Service(
+                name="Lease",
+                elements=[
+                    ast.Method(
+                        name="LeaseRevoke",
+                        input_type=ast.MessageType(
+                            type="LeaseRevokeRequest", stream=False
+                        ),
+                        output_type=ast.MessageType(
+                            type="LeaseRevokeResponse", stream=False
+                        ),
+                        elements=[
+                            ast.Option(
+                                name="(google.api.http)",
+                                value=ast.MessageLiteral(
+                                    fields=[
+                                        ast.MessageLiteralField(
+                                            name="post", value="/v3/lease/revoke"
+                                        ),
+                                        ast.MessageLiteralField(name="body", value="*"),
+                                        ast.MessageLiteralField(
+                                            name="additional_bindings",
+                                            value=ast.MessageLiteral(
+                                                fields=[
+                                                    ast.MessageLiteralField(
+                                                        name="post",
+                                                        value="/v3/kv/lease/revoke",
+                                                    ),
+                                                    ast.MessageLiteralField(
+                                                        name="body", value="*"
+                                                    ),
+                                                ]
+                                            ),
+                                        ),
+                                    ]
+                                ),
+                            )
+                        ],
+                    )
+                ],
+            )
+        ],
+    )
+
+    assert result == expected
+
+
+def test_syntax_error():
+    text = """
+    syntax = "proto3";
+
+    message SearchRequest {
+      string query = 1
+    }
+    """
+
+    import antlr4.error.ErrorListener as antlr4_el
+
+    import proto_schema_parser.antlr.ProtobufParser as psp_antlr
+
+    class _ErrorListener(antlr4_el.ErrorListener):
+        def syntaxError(self, recognizer, offendingSymbol, line, column, msg, e):
+            raise Exception(f"Failed to parse: line {line}:{column}: {msg}")
+
+    def _setup_parser(parser: psp_antlr.ProtobufParser) -> None:
+        parser.addErrorListener(_ErrorListener())
+
+    with pytest.raises(Exception) as exc_info:
+        Parser(setup_parser=_setup_parser).parse(text)
+
+    assert (
+        exc_info.value.args[0]
+        == r"Failed to parse: line 6:4: mismatched input '}' expecting {';', '['}"
+    )
